@@ -6,7 +6,5 @@ from hashedixsearch.search import (  # noqa
     execute_query_exact,
     highlight,
     tokenize,
-    NullAnalyzer,
     NullStemmer,
-    SynonymAnalyzer,
 )
